diff src/version.c @ 10200:b85c507b50f3 v8.0.0001

commit https://github.com/vim/vim/commit/6401024869dcd722ee1b98b4ba58e6caa215201b Author: Bram Moolenaar <Bram@vim.org> Date: Mon Sep 12 16:23:34 2016 +0200 patch 8.0.0001 Problem: Intro screen still mentions version7. (Paul) Solution: Change it to version8.
author Christian Brabandt <cb@256bit.org>
date Mon, 12 Sep 2016 16:30:08 +0200
parents 9f48eab77d62
children 8335fdda6d4d
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -17,8 +17,9 @@
  * Vim originated from Stevie version 3.6 (Fish disk 217) by GRWalter (Fred)
  * It has been changed beyond recognition since then.
  *
  * Differences between version 6.x and 7.x can be found with ":help version7".
  * Differences between version 5.x and 6.x can be found with ":help version6".
  * Differences between version 4.x and 5.x can be found with ":help version5".
  * Differences between version 3.0 and 4.x can be found with ":help version4".
  * All the remarks about older versions have been removed, they are not very
@@ -764,6 +765,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1,
+/**/
     0
 };
 
@@ -1238,7 +1241,7 @@ intro_message(
 	"",
 	N_("type  :q<Enter>               to exit         "),
 	N_("type  :help<Enter>  or  <F1>  for on-line help"),
-	N_("type  :help version7<Enter>   for version info"),
+	N_("type  :help version8<Enter>   for version info"),
 	NULL,
 	"",
 	N_("Running in Vi compatible mode"),
@@ -17,8 +17,9 @@
  * It has been changed beyond recognition since then.
  *
- * Differences between version 6.x and 7.x can be found with ":help version7".
- * Differences between version 5.x and 6.x can be found with ":help version6".
+ * Differences between version 7.4 and 8.x can be found with ":help version8".
+ * Differences between version 6.4 and 7.x can be found with ":help version7".
+ * Differences between version 5.8 and 6.x can be found with ":help version6".
  * Differences between version 4.x and 5.x can be found with ":help version5".
  * Differences between version 3.0 and 4.x can be found with ":help version4".